<?php $TRANSLATIONS = array(
"Pictures" => "Imagens",
"Shared by" => "Partilhado por",
"Share" => "Partilhar",
"The \"Image Viewer\" application also need to be enabled to use this application." => "A aplicação \"Image Viewer\" também precisa de estar activada para usar esta aplicação."
);
